All of lore.kernel.org
 help / color / mirror / Atom feed
* [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
@ 2022-04-08 14:55 Neal Frager via buildroot
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: " Neal Frager via buildroot
                   ` (5 more replies)
  0 siblings, 6 replies; 15+ messages in thread
From: Neal Frager via buildroot @ 2022-04-08 14:55 UTC (permalink / raw)
  To: buildroot; +Cc: luca, giulio.benetti, ju.o, Neal Frager

This patch bumps configs/zynq_zc706_defconfig to Xilinx software release 2021.2
which includes the following updates:
  - U-Boot bumped to 2021.01
  - Linux bumped to 5.10
  - rootfs changed from CPIO to EXT4
  - extlinux.conf for distro boot support

This patch has been build and run tested on a ZC706 evaluation board.

Signed-off-by: Neal Frager <neal.frager@amd.com>
---
 board/zynq/extlinux.conf        |  4 ++++
 board/zynq/genimage.cfg         | 11 ++++++++---
 board/zynq/post-build.sh        |  8 ++++++++
 board/zynq/post-image.sh        | 14 ++++++++------
 board/zynq/zc706/uboot.fragment |  1 +
 configs/zynq_zc706_defconfig    | 20 +++++++++++---------
 6 files changed, 41 insertions(+), 18 deletions(-)
 create mode 100644 board/zynq/extlinux.conf
 create mode 100755 board/zynq/post-build.sh
 create mode 100644 board/zynq/zc706/uboot.fragment

diff --git a/board/zynq/extlinux.conf b/board/zynq/extlinux.conf
new file mode 100644
index 0000000000..b9345906e6
--- /dev/null
+++ b/board/zynq/extlinux.conf
@@ -0,0 +1,4 @@
+label linux
+  kernel /uImage
+  devicetree /system.dtb
+  append console=ttyPS0,115200 root=/dev/mmcblk0p2 rw rootwait
diff --git a/board/zynq/genimage.cfg b/board/zynq/genimage.cfg
index 67baca795e..78eb9275dd 100644
--- a/board/zynq/genimage.cfg
+++ b/board/zynq/genimage.cfg
@@ -3,12 +3,12 @@ image boot.vfat {
 		files = {
 			"boot.bin",
 			"u-boot.img",
-			"devicetree.dtb",
+			"system.dtb",
 			"uImage"
 		}
 
-		file uramdisk.image.gz {
-			image = "rootfs.cpio.uboot"
+		file extlinux/extlinux.conf {
+			image = extlinux.conf
 		}
 	}
 
@@ -24,4 +24,9 @@ image sdcard.img {
 		bootable = "true"
 		image = "boot.vfat"
 	}
+
+	partition rootfs {
+		partition-type = 0x83
+		image = "rootfs.ext4"
+	}
 }
diff --git a/board/zynq/post-build.sh b/board/zynq/post-build.sh
new file mode 100755
index 0000000000..9fd8bbf2c8
--- /dev/null
+++ b/board/zynq/post-build.sh
@@ -0,0 +1,8 @@
+#!/bin/sh
+
+# genimage will need to find the extlinux.conf
+# in the binaries directory
+
+BOARD_DIR="$(dirname $0)"
+
+install -m 0644 -D $BOARD_DIR/extlinux.conf $BINARIES_DIR/extlinux.conf
diff --git a/board/zynq/zc706/uboot.fragment b/board/zynq/zc706/uboot.fragment
new file mode 100644
index 0000000000..ad5efa6204
--- /dev/null
+++ b/board/zynq/zc706/uboot.fragment
@@ -0,0 +1 @@
+CONFIG_DEFAULT_DEVICE_TREE="zynq-zc706"
diff --git a/configs/zynq_zc706_defconfig b/configs/zynq_zc706_defconfig
index e8019177d2..6c2a858f14 100644
--- a/configs/zynq_zc706_defconfig
+++ b/configs/zynq_zc706_defconfig
@@ -2,26 +2,28 @@ BR2_arm=y
 BR2_cortex_a9=y
 BR2_ARM_ENABLE_NEON=y
 BR2_ARM_ENABLE_VFP=y
-BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_9=y
-BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
+BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_5_10=y
+BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
 BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
 BR2_LINUX_KERNEL=y
-BR2_LINUX_KERNEL_CUSTOM_TARBALL=y
-BR2_LINUX_KERNEL_CUSTOM_TARBALL_LOCATION="$(call github,Xilinx,linux-xlnx,xilinx-v2017.3)/linux-xilinx-v2017.3.tar.gz"
+BR2_LINUX_KERNEL_CUSTOM_GIT=y
+BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"
+BR2_LINUX_KERNEL_CUSTOM_REPO_VERSION="xlnx_rebase_v5.10_2021.2"
 BR2_LINUX_KERNEL_DEFCONFIG="xilinx_zynq"
 BR2_LINUX_KERNEL_UIMAGE=y
 BR2_LINUX_KERNEL_UIMAGE_LOADADDR="0x8000"
 BR2_LINUX_KERNEL_DTS_SUPPORT=y
 BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-zc706"
-BR2_TARGET_ROOTFS_CPIO=y
-BR2_TARGET_ROOTFS_CPIO_GZIP=y
-BR2_TARGET_ROOTFS_CPIO_UIMAGE=y
+BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
+BR2_TARGET_ROOTFS_EXT2=y
+BR2_TARGET_ROOTFS_EXT2_4=y
 BR2_TARGET_UBOOT=y
 BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
 BR2_TARGET_UBOOT_CUSTOM_GIT=y
 BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"
-BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xilinx-v2018.2"
-BR2_TARGET_UBOOT_BOARD_DEFCONFIG="zynq_zc706"
+BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xlnx_rebase_v2021.01_2021.2"
+BR2_TARGET_UBOOT_BOARD_DEFCONFIG="xilinx_zynq_virt"
+BR2_TARGET_UBOOT_CONFIG_FRAGMENT_FILES="board/zynq/zc706/uboot.fragment"
 BR2_TARGET_UBOOT_NEEDS_DTC=y
 BR2_TARGET_UBOOT_NEEDS_OPENSSL=y
 BR2_TARGET_UBOOT_FORMAT_IMG=y
-- 
2.17.1

_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply related	[flat|nested] 15+ messages in thread

* [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: bump to Xilinx 2021.2
  2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
@ 2022-04-08 14:55 ` Neal Frager via buildroot
  2022-04-14 19:59   ` Arnout Vandecappelle
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 3/4] configs/zynq_microzed_defconfig: " Neal Frager via buildroot
                   ` (4 subsequent siblings)
  5 siblings, 1 reply; 15+ messages in thread
From: Neal Frager via buildroot @ 2022-04-08 14:55 UTC (permalink / raw)
  To: buildroot; +Cc: luca, giulio.benetti, ju.o, Neal Frager

This patch bumps configs/zynq_zed_defconfig to Xilinx software release 2021.2
which includes the following updates:
  - U-Boot bumped to 2021.01
  - Linux bumped to 5.10
  - rootfs changed from CPIO to EXT4
  - extlinux.conf for distro boot support

This patch has been build tested only.
This patch is dependent on the configs/zynq_zc706_defconfig patch.

Signed-off-by: Neal Frager <neal.frager@amd.com>
---
 board/zynq/zed/uboot.fragment |  1 +
 configs/zynq_zed_defconfig    | 22 ++++++++++++----------
 2 files changed, 13 insertions(+), 10 deletions(-)
 create mode 100644 board/zynq/zed/uboot.fragment

diff --git a/board/zynq/zed/uboot.fragment b/board/zynq/zed/uboot.fragment
new file mode 100644
index 0000000000..d58fcd5439
--- /dev/null
+++ b/board/zynq/zed/uboot.fragment
@@ -0,0 +1 @@
+CONFIG_DEFAULT_DEVICE_TREE="zynq-zed"
diff --git a/configs/zynq_zed_defconfig b/configs/zynq_zed_defconfig
index a215695b54..c4d95f20b7 100644
--- a/configs/zynq_zed_defconfig
+++ b/configs/zynq_zed_defconfig
@@ -2,26 +2,28 @@ BR2_arm=y
 BR2_cortex_a9=y
 BR2_ARM_ENABLE_NEON=y
 BR2_ARM_ENABLE_VFP=y
-BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_16=y
-BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
+BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_5_10=y
+BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
 BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
 BR2_LINUX_KERNEL=y
-BR2_LINUX_KERNEL_CUSTOM_VERSION=y
-BR2_LINUX_KERNEL_CUSTOM_VERSION_VALUE="4.16"
-BR2_LINUX_KERNEL_USE_ARCH_DEFAULT_CONFIG=y
+BR2_LINUX_KERNEL_CUSTOM_GIT=y
+BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"
+BR2_LINUX_KERNEL_CUSTOM_REPO_VERSION="xlnx_rebase_v5.10_2021.2"
+BR2_LINUX_KERNEL_DEFCONFIG="xilinx_zynq"
 BR2_LINUX_KERNEL_UIMAGE=y
 BR2_LINUX_KERNEL_UIMAGE_LOADADDR="0x8000"
 BR2_LINUX_KERNEL_DTS_SUPPORT=y
 BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-zed"
-BR2_TARGET_ROOTFS_CPIO=y
-BR2_TARGET_ROOTFS_CPIO_GZIP=y
-BR2_TARGET_ROOTFS_CPIO_UIMAGE=y
+BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
+BR2_TARGET_ROOTFS_EXT2=y
+BR2_TARGET_ROOTFS_EXT2_4=y
 BR2_TARGET_UBOOT=y
 BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
 BR2_TARGET_UBOOT_CUSTOM_GIT=y
 BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"
-BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xilinx-v2018.2"
-BR2_TARGET_UBOOT_BOARD_DEFCONFIG="zynq_zed"
+BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xlnx_rebase_v2021.01_2021.2"
+BR2_TARGET_UBOOT_BOARD_DEFCONFIG="xilinx_zynq_virt"
+BR2_TARGET_UBOOT_CONFIG_FRAGMENT_FILES="board/zynq/zed/uboot.fragment"
 BR2_TARGET_UBOOT_NEEDS_DTC=y
 BR2_TARGET_UBOOT_NEEDS_OPENSSL=y
 BR2_TARGET_UBOOT_FORMAT_IMG=y
-- 
2.17.1

_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply related	[flat|nested] 15+ messages in thread

* [Buildroot] [PATCH v1 3/4] configs/zynq_microzed_defconfig: bump to Xilinx 2021.2
  2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: " Neal Frager via buildroot
@ 2022-04-08 14:55 ` Neal Frager via buildroot
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 4/4] configs/zynq_qmtech_defconfig: bump to ext4 and distro boot Neal Frager via buildroot
                   ` (3 subsequent siblings)
  5 siblings, 0 replies; 15+ messages in thread
From: Neal Frager via buildroot @ 2022-04-08 14:55 UTC (permalink / raw)
  To: buildroot; +Cc: luca, giulio.benetti, ju.o, Neal Frager

This patch bumps configs/zynq_microzed_defconfig to Xilinx software release 2021.2
which includes the following updates:
  - U-Boot bumped to 2021.01
  - Linux bumped to 5.10
  - rootfs changed from CPIO to EXT4
  - extlinux.conf for distro boot support

This patch has been build tested only.
This patch is dependent on the configs/zynq_zc706_defconfig patch.

Signed-off-by: Neal Frager <neal.frager@amd.com>
---
 board/zynq/microzed/uboot.fragment |  1 +
 configs/zynq_microzed_defconfig    | 22 ++++++++++++----------
 2 files changed, 13 insertions(+), 10 deletions(-)
 create mode 100644 board/zynq/microzed/uboot.fragment

diff --git a/board/zynq/microzed/uboot.fragment b/board/zynq/microzed/uboot.fragment
new file mode 100644
index 0000000000..bc4dffaffa
--- /dev/null
+++ b/board/zynq/microzed/uboot.fragment
@@ -0,0 +1 @@
+CONFIG_DEFAULT_DEVICE_TREE="zynq-microzed"
diff --git a/configs/zynq_microzed_defconfig b/configs/zynq_microzed_defconfig
index 1bb11fee7e..f1f98086a8 100644
--- a/configs/zynq_microzed_defconfig
+++ b/configs/zynq_microzed_defconfig
@@ -2,26 +2,28 @@ BR2_arm=y
 BR2_cortex_a9=y
 BR2_ARM_ENABLE_NEON=y
 BR2_ARM_ENABLE_VFP=y
-BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_9=y
-BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
+BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_5_10=y
+BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
 BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
 BR2_LINUX_KERNEL=y
-BR2_LINUX_KERNEL_CUSTOM_TARBALL=y
-BR2_LINUX_KERNEL_CUSTOM_TARBALL_LOCATION="$(call github,Xilinx,linux-xlnx,xilinx-v2017.3)/linux-xilinx-v2017.3.tar.gz"
+BR2_LINUX_KERNEL_CUSTOM_GIT=y
+BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"
+BR2_LINUX_KERNEL_CUSTOM_REPO_VERSION="xlnx_rebase_v5.10_2021.2"
 BR2_LINUX_KERNEL_DEFCONFIG="xilinx_zynq"
 BR2_LINUX_KERNEL_UIMAGE=y
 BR2_LINUX_KERNEL_UIMAGE_LOADADDR="0x8000"
 BR2_LINUX_KERNEL_DTS_SUPPORT=y
-BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-zed"
-BR2_TARGET_ROOTFS_CPIO=y
-BR2_TARGET_ROOTFS_CPIO_GZIP=y
-BR2_TARGET_ROOTFS_CPIO_UIMAGE=y
+BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-microzed"
+BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
+BR2_TARGET_ROOTFS_EXT2=y
+BR2_TARGET_ROOTFS_EXT2_4=y
 BR2_TARGET_UBOOT=y
 BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
 BR2_TARGET_UBOOT_CUSTOM_GIT=y
 BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"
-BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xilinx-v2018.2"
-BR2_TARGET_UBOOT_BOARD_DEFCONFIG="zynq_microzed"
+BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xlnx_rebase_v2021.01_2021.2"
+BR2_TARGET_UBOOT_BOARD_DEFCONFIG="xilinx_zynq_virt"
+BR2_TARGET_UBOOT_CONFIG_FRAGMENT_FILES="board/zynq/microzed/uboot.fragment"
 BR2_TARGET_UBOOT_NEEDS_DTC=y
 BR2_TARGET_UBOOT_NEEDS_OPENSSL=y
 BR2_TARGET_UBOOT_FORMAT_IMG=y
-- 
2.17.1

_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply related	[flat|nested] 15+ messages in thread

* [Buildroot] [PATCH v1 4/4] configs/zynq_qmtech_defconfig: bump to ext4 and distro boot
  2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: " Neal Frager via buildroot
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 3/4] configs/zynq_microzed_defconfig: " Neal Frager via buildroot
@ 2022-04-08 14:55 ` Neal Frager via buildroot
  2022-04-14  8:55 ` [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager
                   ` (2 subsequent siblings)
  5 siblings, 0 replies; 15+ messages in thread
From: Neal Frager via buildroot @ 2022-04-08 14:55 UTC (permalink / raw)
  To: buildroot; +Cc: luca, giulio.benetti, ju.o, Neal Frager

This patch includes the following updates for configs/zynq_qmtech_defconfig:
  - rootfs changed from CPIO to EXT4
  - extlinux.conf for distro boot support
  - enables support for host machines without OpenSSL required by U-Boot and Linux

This patch is necessary to support the new board/zynq/post-image.sh.
This patch has been build tested only.
This patch is dependent on the configs/zynq_zc706_defconfig patch.

Signed-off-by: Neal Frager <neal.frager@amd.com>
---
 configs/zynq_qmtech_defconfig | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/configs/zynq_qmtech_defconfig b/configs/zynq_qmtech_defconfig
index 4db3f68b1f..f536b80f57 100644
--- a/configs/zynq_qmtech_defconfig
+++ b/configs/zynq_qmtech_defconfig
@@ -5,6 +5,7 @@ BR2_ARM_ENABLE_VFP=y
 BR2_GLOBAL_PATCH_DIR="board/qmtech/zynq/patches"
 BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_19=y
 BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
+BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
 BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
 BR2_LINUX_KERNEL=y
 BR2_LINUX_KERNEL_CUSTOM_TARBALL=y
@@ -14,9 +15,9 @@ BR2_LINUX_KERNEL_UIMAGE=y
 BR2_LINUX_KERNEL_UIMAGE_LOADADDR="0x8000"
 BR2_LINUX_KERNEL_DTS_SUPPORT=y
 BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-qmtech"
-BR2_TARGET_ROOTFS_CPIO=y
-BR2_TARGET_ROOTFS_CPIO_GZIP=y
-BR2_TARGET_ROOTFS_CPIO_UIMAGE=y
+BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
+BR2_TARGET_ROOTFS_EXT2=y
+BR2_TARGET_ROOTFS_EXT2_4=y
 BR2_TARGET_UBOOT=y
 BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
 BR2_TARGET_UBOOT_CUSTOM_TARBALL=y
diff --git a/board/zynq/post-image.sh b/board/zynq/post-image.sh
index 0cf92e0aa9..bf88aa7cd1 100755
--- a/board/zynq/post-image.sh
+++ b/board/zynq/post-image.sh
@@ -1,13 +1,15 @@
 #!/bin/sh
 
 # By default U-Boot loads DTB from a file named "devicetree.dtb", so
 # let's use a symlink with that name that points to the *first*
 # devicetree listed in the config.
 
-FIRST_DT=$(sed -n \
-           's/^BR2_LINUX_KERNEL_INTREE_DTS_NAME="\([a-z0-9\-]*\).*"$/\1/p' \
-           ${BR2_CONFIG})
+FIRST_DT=$(sed -nr \
+               -e 's|^BR2_LINUX_KERNEL_INTREE_DTS_NAME="([-_/[:alnum:]\\.]*).*"$|\1|p' \
+               ${BR2_CONFIG})
 
-[ -z "${FIRST_DT}" ] || ln -fs ${FIRST_DT}.dtb ${BINARIES_DIR}/devicetree.dtb
+[ -z "${FIRST_DT}" ] || ln -fs ${FIRST_DT}.dtb ${BINARIES_DIR}/system.dtb
 
-support/scripts/genimage.sh -c board/zynq/genimage.cfg
+BOARD_DIR="$(dirname $0)"
+
+support/scripts/genimage.sh -c $BOARD_DIR/genimage.cfg
@@ -1,13 +1,15 @@
 #!/bin/sh
 
-# By default U-Boot loads DTB from a file named "devicetree.dtb", so
+# By default U-Boot loads DTB from a file named "system.dtb", so
 # let's use a symlink with that name that points to the *first*
 # devicetree listed in the config.
-- 
2.17.1

_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply related	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
                   ` (2 preceding siblings ...)
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 4/4] configs/zynq_qmtech_defconfig: bump to ext4 and distro boot Neal Frager via buildroot
@ 2022-04-14  8:55 ` Neal Frager
  2022-04-14 19:54 ` Arnout Vandecappelle
  2022-04-14 22:20 ` Luca Ceresoli
  5 siblings, 0 replies; 15+ messages in thread
From: Neal Frager @ 2022-04-14  8:55 UTC (permalink / raw)
  To: Neal Frager, buildroot; +Cc: luca, giulio.benetti, ju.o

Hello everyone,

Just a friendly reminder regarding the zynq defconfigs update.  Any feedback?

> This patch bumps configs/zynq_zc706_defconfig to Xilinx software release 2021.2 which includes the following updates:
>  - U-Boot bumped to 2021.01
>  - Linux bumped to 5.10
>  - rootfs changed from CPIO to EXT4
>  - extlinux.conf for distro boot support

> This patch has been build and run tested on a ZC706 evaluation board.

> Signed-off-by: Neal Frager <neal.frager@amd.com>

Thank you for your support!

Best regards,
Neal Frager
AMD
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
                   ` (3 preceding siblings ...)
  2022-04-14  8:55 ` [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager
@ 2022-04-14 19:54 ` Arnout Vandecappelle
  2022-04-15  6:52   ` Neal Frager
  2022-04-14 22:20 ` Luca Ceresoli
  5 siblings, 1 reply; 15+ messages in thread
From: Arnout Vandecappelle @ 2022-04-14 19:54 UTC (permalink / raw)
  To: Neal Frager, buildroot; +Cc: luca, giulio.benetti, ju.o



On 08/04/2022 16:55, Neal Frager via buildroot wrote:
> This patch bumps configs/zynq_zc706_defconfig to Xilinx software release 2021.2
> which includes the following updates:
>    - U-Boot bumped to 2021.01
>    - Linux bumped to 5.10
>    - rootfs changed from CPIO to EXT4
>    - extlinux.conf for distro boot support
> 
> This patch has been build and run tested on a ZC706 evaluation board.
> 
> Signed-off-by: Neal Frager <neal.frager@amd.com>
> ---
>   board/zynq/extlinux.conf        |  4 ++++
>   board/zynq/genimage.cfg         | 11 ++++++++---
>   board/zynq/post-build.sh        |  8 ++++++++
>   board/zynq/post-image.sh        | 14 ++++++++------
>   board/zynq/zc706/uboot.fragment |  1 +
>   configs/zynq_zc706_defconfig    | 20 +++++++++++---------
>   6 files changed, 41 insertions(+), 18 deletions(-)
>   create mode 100644 board/zynq/extlinux.conf
>   create mode 100755 board/zynq/post-build.sh
>   create mode 100644 board/zynq/zc706/uboot.fragment
> 
> diff --git a/board/zynq/extlinux.conf b/board/zynq/extlinux.conf
> new file mode 100644
> index 0000000000..b9345906e6
> --- /dev/null
> +++ b/board/zynq/extlinux.conf
> @@ -0,0 +1,4 @@
> +label linux
> +  kernel /uImage
> +  devicetree /system.dtb
> +  append console=ttyPS0,115200 root=/dev/mmcblk0p2 rw rootwait
> diff --git a/board/zynq/genimage.cfg b/board/zynq/genimage.cfg
> index 67baca795e..78eb9275dd 100644
> --- a/board/zynq/genimage.cfg
> +++ b/board/zynq/genimage.cfg
> @@ -3,12 +3,12 @@ image boot.vfat {
>   		files = {
>   			"boot.bin",
>   			"u-boot.img",
> -			"devicetree.dtb",
> +			"system.dtb",
>   			"uImage"
>   		}
>   
> -		file uramdisk.image.gz {
> -			image = "rootfs.cpio.uboot"
> +		file extlinux/extlinux.conf {
> +			image = extlinux.conf
>   		}
>   	}
>   
> @@ -24,4 +24,9 @@ image sdcard.img {
>   		bootable = "true"
>   		image = "boot.vfat"
>   	}
> +
> +	partition rootfs {
> +		partition-type = 0x83
> +		image = "rootfs.ext4"
> +	}
>   }
> diff --git a/board/zynq/post-build.sh b/board/zynq/post-build.sh
> new file mode 100755
> index 0000000000..9fd8bbf2c8
> --- /dev/null
> +++ b/board/zynq/post-build.sh
> @@ -0,0 +1,8 @@
> +#!/bin/sh
> +
> +# genimage will need to find the extlinux.conf
> +# in the binaries directory
> +
> +BOARD_DIR="$(dirname $0)"
> +
> +install -m 0644 -D $BOARD_DIR/extlinux.conf $BINARIES_DIR/extlinux.conf
> diff --git a/board/zynq/post-image.sh b/board/zynq/post-image.sh
> index 0cf92e0aa9..bf88aa7cd1 100755
> --- a/board/zynq/post-image.sh
> +++ b/board/zynq/post-image.sh
> @@ -1,13 +1,15 @@
>   #!/bin/sh
>   
> -# By default U-Boot loads DTB from a file named "devicetree.dtb", so
> +# By default U-Boot loads DTB from a file named "system.dtb", so
>   # let's use a symlink with that name that points to the *first*
>   # devicetree listed in the config.
>   
> -FIRST_DT=$(sed -n \
> -           's/^BR2_LINUX_KERNEL_INTREE_DTS_NAME="\([a-z0-9\-]*\).*"$/\1/p' \
> -           ${BR2_CONFIG})
> +FIRST_DT=$(sed -nr \
> +               -e 's|^BR2_LINUX_KERNEL_INTREE_DTS_NAME="([-_/[:alnum:]\\.]*).*"$|\1|p' \
> +               ${BR2_CONFIG})
>   
> -[ -z "${FIRST_DT}" ] || ln -fs ${FIRST_DT}.dtb ${BINARIES_DIR}/devicetree.dtb
> +[ -z "${FIRST_DT}" ] || ln -fs ${FIRST_DT}.dtb ${BINARIES_DIR}/system.dtb
>   
> -support/scripts/genimage.sh -c board/zynq/genimage.cfg
> +BOARD_DIR="$(dirname $0)"
> +
> +support/scripts/genimage.sh -c $BOARD_DIR/genimage.cfg
> diff --git a/board/zynq/zc706/uboot.fragment b/board/zynq/zc706/uboot.fragment
> new file mode 100644
> index 0000000000..ad5efa6204
> --- /dev/null
> +++ b/board/zynq/zc706/uboot.fragment
> @@ -0,0 +1 @@
> +CONFIG_DEFAULT_DEVICE_TREE="zynq-zc706"
> diff --git a/configs/zynq_zc706_defconfig b/configs/zynq_zc706_defconfig
> index e8019177d2..6c2a858f14 100644
> --- a/configs/zynq_zc706_defconfig
> +++ b/configs/zynq_zc706_defconfig
> @@ -2,26 +2,28 @@ BR2_arm=y
>   BR2_cortex_a9=y
>   BR2_ARM_ENABLE_NEON=y
>   BR2_ARM_ENABLE_VFP=y
> -BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_9=y
> -BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
> +BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_5_10=y
> +BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
>   BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
>   BR2_LINUX_KERNEL=y
> -BR2_LINUX_KERNEL_CUSTOM_TARBALL=y
> -BR2_LINUX_KERNEL_CUSTOM_TARBALL_LOCATION="$(call github,Xilinx,linux-xlnx,xilinx-v2017.3)/linux-xilinx-v2017.3.tar.gz"
> +BR2_LINUX_KERNEL_CUSTOM_GIT=y
> +BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"

  This is not so nice, we prefer the tarball download (it's a lot faster if the 
repo has never been cloned before, and not much slower if the git repo was 
already cloned; in addition, it's subject to github rate limiting).

> +BR2_LINUX_KERNEL_CUSTOM_REPO_VERSION="xlnx_rebase_v5.10_2021.2"
>   BR2_LINUX_KERNEL_DEFCONFIG="xilinx_zynq"
>   BR2_LINUX_KERNEL_UIMAGE=y
>   BR2_LINUX_KERNEL_UIMAGE_LOADADDR="0x8000"
>   BR2_LINUX_KERNEL_DTS_SUPPORT=y
>   BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-zc706"
> -BR2_TARGET_ROOTFS_CPIO=y
> -BR2_TARGET_ROOTFS_CPIO_GZIP=y
> -BR2_TARGET_ROOTFS_CPIO_UIMAGE=y
> +BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
> +BR2_TARGET_ROOTFS_EXT2=y
> +BR2_TARGET_ROOTFS_EXT2_4=y
>   BR2_TARGET_UBOOT=y
>   BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
>   BR2_TARGET_UBOOT_CUSTOM_GIT=y
>   BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"

  Actually you could switch this to tarball as well.

  Regards,
  Arnout


> -BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xilinx-v2018.2"
> -BR2_TARGET_UBOOT_BOARD_DEFCONFIG="zynq_zc706"
> +BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xlnx_rebase_v2021.01_2021.2"
> +BR2_TARGET_UBOOT_BOARD_DEFCONFIG="xilinx_zynq_virt"
> +BR2_TARGET_UBOOT_CONFIG_FRAGMENT_FILES="board/zynq/zc706/uboot.fragment"
>   BR2_TARGET_UBOOT_NEEDS_DTC=y
>   BR2_TARGET_UBOOT_NEEDS_OPENSSL=y
>   BR2_TARGET_UBOOT_FORMAT_IMG=y
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: bump to Xilinx 2021.2
  2022-04-08 14:55 ` [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: " Neal Frager via buildroot
@ 2022-04-14 19:59   ` Arnout Vandecappelle
  2022-04-14 22:24     ` Luca Ceresoli
  2022-04-15  7:01     ` Neal Frager
  0 siblings, 2 replies; 15+ messages in thread
From: Arnout Vandecappelle @ 2022-04-14 19:59 UTC (permalink / raw)
  To: Neal Frager, buildroot; +Cc: luca, giulio.benetti, ju.o



On 08/04/2022 16:55, Neal Frager via buildroot wrote:
> This patch bumps configs/zynq_zed_defconfig to Xilinx software release 2021.2
> which includes the following updates:
>    - U-Boot bumped to 2021.01
>    - Linux bumped to 5.10
>    - rootfs changed from CPIO to EXT4
>    - extlinux.conf for distro boot support
> 
> This patch has been build tested only.
> This patch is dependent on the configs/zynq_zc706_defconfig patch.
> 
> Signed-off-by: Neal Frager <neal.frager@amd.com>
> ---
>   board/zynq/zed/uboot.fragment |  1 +
>   configs/zynq_zed_defconfig    | 22 ++++++++++++----------
>   2 files changed, 13 insertions(+), 10 deletions(-)
>   create mode 100644 board/zynq/zed/uboot.fragment
> 
> diff --git a/board/zynq/zed/uboot.fragment b/board/zynq/zed/uboot.fragment
> new file mode 100644
> index 0000000000..d58fcd5439
> --- /dev/null
> +++ b/board/zynq/zed/uboot.fragment
> @@ -0,0 +1 @@
> +CONFIG_DEFAULT_DEVICE_TREE="zynq-zed"
> diff --git a/configs/zynq_zed_defconfig b/configs/zynq_zed_defconfig
> index a215695b54..c4d95f20b7 100644
> --- a/configs/zynq_zed_defconfig
> +++ b/configs/zynq_zed_defconfig
> @@ -2,26 +2,28 @@ BR2_arm=y
>   BR2_cortex_a9=y
>   BR2_ARM_ENABLE_NEON=y
>   BR2_ARM_ENABLE_VFP=y
> -BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_16=y
> -BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
> +BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_5_10=y
> +BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
>   BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
>   BR2_LINUX_KERNEL=y
> -BR2_LINUX_KERNEL_CUSTOM_VERSION=y
> -BR2_LINUX_KERNEL_CUSTOM_VERSION_VALUE="4.16"
> -BR2_LINUX_KERNEL_USE_ARCH_DEFAULT_CONFIG=y
> +BR2_LINUX_KERNEL_CUSTOM_GIT=y
> +BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"

  We generally prefer to use the upstream kernel rather than a vendor kernel - 
if it works of course. Is the vendor kernel dramatically better than upstream?


> +BR2_LINUX_KERNEL_CUSTOM_REPO_VERSION="xlnx_rebase_v5.10_2021.2"

  There's also a xilinx-v2021.2 tag, which sounds more like what we'd want to use.

  Regards,
  Arnout

> +BR2_LINUX_KERNEL_DEFCONFIG="xilinx_zynq"
>   BR2_LINUX_KERNEL_UIMAGE=y
>   BR2_LINUX_KERNEL_UIMAGE_LOADADDR="0x8000"
>   BR2_LINUX_KERNEL_DTS_SUPPORT=y
>   BR2_LINUX_KERNEL_INTREE_DTS_NAME="zynq-zed"
> -BR2_TARGET_ROOTFS_CPIO=y
> -BR2_TARGET_ROOTFS_CPIO_GZIP=y
> -BR2_TARGET_ROOTFS_CPIO_UIMAGE=y
> +BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
> +BR2_TARGET_ROOTFS_EXT2=y
> +BR2_TARGET_ROOTFS_EXT2_4=y
>   BR2_TARGET_UBOOT=y
>   BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
>   BR2_TARGET_UBOOT_CUSTOM_GIT=y
>   BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"
> -BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xilinx-v2018.2"
> -BR2_TARGET_UBOOT_BOARD_DEFCONFIG="zynq_zed"
> +BR2_TARGET_UBOOT_CUSTOM_REPO_VERSION="xlnx_rebase_v2021.01_2021.2"
> +BR2_TARGET_UBOOT_BOARD_DEFCONFIG="xilinx_zynq_virt"
> +BR2_TARGET_UBOOT_CONFIG_FRAGMENT_FILES="board/zynq/zed/uboot.fragment"
>   BR2_TARGET_UBOOT_NEEDS_DTC=y
>   BR2_TARGET_UBOOT_NEEDS_OPENSSL=y
>   BR2_TARGET_UBOOT_FORMAT_IMG=y
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
                   ` (4 preceding siblings ...)
  2022-04-14 19:54 ` Arnout Vandecappelle
@ 2022-04-14 22:20 ` Luca Ceresoli
  2022-04-15  7:11   ` Neal Frager
  5 siblings, 1 reply; 15+ messages in thread
From: Luca Ceresoli @ 2022-04-14 22:20 UTC (permalink / raw)
  To: Neal Frager, buildroot; +Cc: giulio.benetti, ju.o

Hi Neal,

On 08/04/22 16:55, Neal Frager wrote:
> This patch bumps configs/zynq_zc706_defconfig to Xilinx software release 2021.2
> which includes the following updates:
>   - U-Boot bumped to 2021.01
>   - Linux bumped to 5.10
>   - rootfs changed from CPIO to EXT4
>   - extlinux.conf for distro boot support
> 
> This patch has been build and run tested on a ZC706 evaluation board.

Thank you for these patches and apologies for the delayed reply.

I have one remark in addition to Arnout's.

> --- a/board/zynq/post-image.sh
> +++ b/board/zynq/post-image.sh
> @@ -1,13 +1,15 @@
>  #!/bin/sh
>  
> -# By default U-Boot loads DTB from a file named "devicetree.dtb", so
> +# By default U-Boot loads DTB from a file named "system.dtb", so
>  # let's use a symlink with that name that points to the *first*
>  # devicetree listed in the config.
>  
> -FIRST_DT=$(sed -n \
> -           's/^BR2_LINUX_KERNEL_INTREE_DTS_NAME="\([a-z0-9\-]*\).*"$/\1/p' \
> -           ${BR2_CONFIG})
> +FIRST_DT=$(sed -nr \
> +               -e 's|^BR2_LINUX_KERNEL_INTREE_DTS_NAME="([-_/[:alnum:]\\.]*).*"$|\1|p' \
> +               ${BR2_CONFIG})

Why do you need this change? I think the old, simpler sed expression
should be still working. BR2_LINUX_KERNEL_INTREE_DTS_NAME is not exev
changed by this patch.

Otherwise looks fine.

-- 
Luca
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: bump to Xilinx 2021.2
  2022-04-14 19:59   ` Arnout Vandecappelle
@ 2022-04-14 22:24     ` Luca Ceresoli
  2022-04-15  7:01     ` Neal Frager
  1 sibling, 0 replies; 15+ messages in thread
From: Luca Ceresoli @ 2022-04-14 22:24 UTC (permalink / raw)
  To: Arnout Vandecappelle, Neal Frager, buildroot; +Cc: giulio.benetti, ju.o

hI aRNOUT, nEAL,Hi Neal, Arnout,

On 14/04/22 21:59, Arnout Vandecappelle wrote:
>> --- a/configs/zynq_zed_defconfig
>> +++ b/configs/zynq_zed_defconfig
>> @@ -2,26 +2,28 @@ BR2_arm=y
>>   BR2_cortex_a9=y
>>   BR2_ARM_ENABLE_NEON=y
>>   BR2_ARM_ENABLE_VFP=y
>> -BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_4_16=y
>> -BR2_TARGET_GENERIC_GETTY_PORT="ttyPS0"
>> +BR2_PACKAGE_HOST_LINUX_HEADERS_CUSTOM_5_10=y
>> +BR2_ROOTFS_POST_BUILD_SCRIPT="board/zynq/post-build.sh"
>>   BR2_ROOTFS_POST_IMAGE_SCRIPT="board/zynq/post-image.sh"
>>   BR2_LINUX_KERNEL=y
>> -BR2_LINUX_KERNEL_CUSTOM_VERSION=y
>> -BR2_LINUX_KERNEL_CUSTOM_VERSION_VALUE="4.16"
>> -BR2_LINUX_KERNEL_USE_ARCH_DEFAULT_CONFIG=y
>> +BR2_LINUX_KERNEL_CUSTOM_GIT=y
>> +BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"
>>
> 
>  We generally prefer to use the upstream kernel rather than a vendor
> kernel - if it works of course. Is the vendor kernel dramatically better
> than upstream?

Indeed I would expect to see zcu706 switch to mainline rather than
another board switch to non-mainline. zynq7 has very good mainline
support since quite a long time as far as I know.

-- 
Luca
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-14 19:54 ` Arnout Vandecappelle
@ 2022-04-15  6:52   ` Neal Frager
  2022-04-17  6:48     ` Neal Frager
  0 siblings, 1 reply; 15+ messages in thread
From: Neal Frager @ 2022-04-15  6:52 UTC (permalink / raw)
  To: Arnout Vandecappelle, Neal Frager, buildroot; +Cc: luca, giulio.benetti, ju.o

Hi Arnout,

> -BR2_LINUX_KERNEL_CUSTOM_TARBALL=y
> -BR2_LINUX_KERNEL_CUSTOM_TARBALL_LOCATION="$(call github,Xilinx,linux-xlnx,xilinx-v2017.3)/linux-xilinx-v2017.3.tar.gz"
> +BR2_LINUX_KERNEL_CUSTOM_GIT=y
> +BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"

>  This is not so nice, we prefer the tarball download (it's a lot faster if the repo has never been cloned before, and not much slower if the git repo was already cloned; in addition, it's subject to github rate limiting).

I was not aware of a significant difference between the tarball download and git cloning.
I only made this change in order to make the zynq defconfigs consistent with the zynqmp defconfigs which use git cloning.
My only preference is to keep the zynq and zynqmp defconfigs as consistent and similar as possible.
If the buildroot community prefers tarballs, then I will move both the zynq and zynqmp defconfigs to tarballs.

>   BR2_TARGET_UBOOT_CUSTOM_GIT=y
>   BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"

>  Actually you could switch this to tarball as well.

Same comment as above.

Best regards,
Neal Frager
AMD
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: bump to Xilinx 2021.2
  2022-04-14 19:59   ` Arnout Vandecappelle
  2022-04-14 22:24     ` Luca Ceresoli
@ 2022-04-15  7:01     ` Neal Frager
  1 sibling, 0 replies; 15+ messages in thread
From: Neal Frager @ 2022-04-15  7:01 UTC (permalink / raw)
  To: Arnout Vandecappelle, Neal Frager, buildroot; +Cc: luca, giulio.benetti, ju.o

Hi Arnout,

> +BR2_LINUX_KERNEL_CUSTOM_GIT=y
> +BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"

>   We generally prefer to use the upstream kernel rather than a vendor kernel - if it works of course. Is the vendor kernel dramatically better than upstream?

I understand.  Unfortunately, not all of the zynq and zynqmp peripheral drivers are fully upstream to mainline.
This often causes support issues on our side.  Specifically for peripherals like usb and qspi.
Developers are certainly free to choose whichever u-boot or Linux kernel version they want.
However, I see these defconfigs as promotional examples of how to use Xilinx zynq SoCs on our evaluation boards.
Since we only perform production and regression testing on our software releases, 
my preference would be to keep the Xilinx defconfigs on the Xilinx github for now.

> +BR2_LINUX_KERNEL_CUSTOM_REPO_VERSION="xlnx_rebase_v5.10_2021.2"

>  There's also a xilinx-v2021.2 tag, which sounds more like what we'd want to use.

The xilinx-v2021.2 tag is functionally identical to the xlnx_rebase_v5.10_2021.2 tag.
I tend to like the xlnx_rebase_v5.10_2021.2 tag name because it includes the Linux kernel version in the tag name.
Same comment for the xlnx_rebase_v2021.01_2021.2 u-boot tag name.

Best regards,
Neal Frager
AMD
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-14 22:20 ` Luca Ceresoli
@ 2022-04-15  7:11   ` Neal Frager
  0 siblings, 0 replies; 15+ messages in thread
From: Neal Frager @ 2022-04-15  7:11 UTC (permalink / raw)
  To: Luca Ceresoli, Neal Frager, buildroot; +Cc: giulio.benetti, ju.o

Hi Luca,

> -FIRST_DT=$(sed -n \
> -           's/^BR2_LINUX_KERNEL_INTREE_DTS_NAME="\([a-z0-9\-]*\).*"$/\1/p' \
> -           ${BR2_CONFIG})
> +FIRST_DT=$(sed -nr \
> +               -e 's|^BR2_LINUX_KERNEL_INTREE_DTS_NAME="([-_/[:alnum:]\\.]*).*"$|\1|p' \
> +               ${BR2_CONFIG})

> Why do you need this change? I think the old, simpler sed expression should be still working. BR2_LINUX_KERNEL_INTREE_DTS_NAME is not exev changed by this patch.

You are correct that this change is not required.  I simply made this change for making the zynq post-image.sh consistent with the zynqmp post-image.sh.
I am happy to remove this change from the patch, since the two versions are still not identical anyway (zynqmp has an extra xilinx directory in the DTS path).

> Otherwise looks fine.

Thank you.

Best regards,
Neal Frager
AMD
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-15  6:52   ` Neal Frager
@ 2022-04-17  6:48     ` Neal Frager
  2022-05-02  7:43       ` Neal Frager
  0 siblings, 1 reply; 15+ messages in thread
From: Neal Frager @ 2022-04-17  6:48 UTC (permalink / raw)
  To: Arnout Vandecappelle, Neal Frager, buildroot, peter
  Cc: luca, giulio.benetti, ju.o

Hi Peter,


> Le 15 avr. 2022 à 08:52, Neal Frager <nealf@xilinx.com> a écrit :
> 
> Hi Arnout,
> 
>> -BR2_LINUX_KERNEL_CUSTOM_TARBALL=y
>> -BR2_LINUX_KERNEL_CUSTOM_TARBALL_LOCATION="$(call github,Xilinx,linux-xlnx,xilinx-v2017.3)/linux-xilinx-v2017.3.tar.gz"
>> +BR2_LINUX_KERNEL_CUSTOM_GIT=y
>> +BR2_LINUX_KERNEL_CUSTOM_REPO_URL="https://github.com/Xilinx/linux-xlnx.git"
> 
>> This is not so nice, we prefer the tarball download (it's a lot faster if the repo has never been cloned before, and not much slower if the git repo was already cloned; in addition, it's subject to github rate limiting).
> 
> I was not aware of a significant difference between the tarball download and git cloning.
> I only made this change in order to make the zynq defconfigs consistent with the zynqmp defconfigs which use git cloning.
> My only preference is to keep the zynq and zynqmp defconfigs as consistent and similar as possible.
> If the buildroot community prefers tarballs, then I will move both the zynq and zynqmp defconfigs to tarballs.
> 

Would you mind weighing in on this?  Does the buildroot community prefer tarballs or git cloning?

From my side, I just want the zynq and the zynqmp defconfigs to be consistent.  So all using the same tarball or git clone format.

Aside from that, I am happy to go either way based on the preference of the buildroot community.

>>  BR2_TARGET_UBOOT_CUSTOM_GIT=y
>>  BR2_TARGET_UBOOT_CUSTOM_REPO_URL="https://github.com/Xilinx/u-boot-xlnx.git"
> 
>> Actually you could switch this to tarball as well.
> 
> Same comment as above.

Best regards,
Neal Frager
AMD
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-04-17  6:48     ` Neal Frager
@ 2022-05-02  7:43       ` Neal Frager
  2022-05-02  7:57         ` Peter Korsgaard
  0 siblings, 1 reply; 15+ messages in thread
From: Neal Frager @ 2022-05-02  7:43 UTC (permalink / raw)
  To: Neal Frager, Arnout Vandecappelle, Neal Frager, buildroot, peter
  Cc: luca, giulio.benetti, ju.o

Hello everyone,

As Xilinx has just released our software version 2022.1, I am going to submit a new patch set bumping the zynq defconfigs to 2022.1 instead of 2021.2.

Based on the feedback, I will keep the defconfigs using tarballs instead of git cloning.  I plan to migrate the zynqmp defconfigs to tarballs as well.

Do not hesitate if you have any additional feedback or questions.

Best regards,
Neal Frager
AMD

_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

* Re: [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2
  2022-05-02  7:43       ` Neal Frager
@ 2022-05-02  7:57         ` Peter Korsgaard
  0 siblings, 0 replies; 15+ messages in thread
From: Peter Korsgaard @ 2022-05-02  7:57 UTC (permalink / raw)
  To: Neal Frager; +Cc: Neal Frager, ju.o, buildroot, luca, giulio.benetti

>>>>> "Neal" == Neal Frager <nealf@xilinx.com> writes:

 > Hello everyone,
 > As Xilinx has just released our software version 2022.1, I am going to
 > submit a new patch set bumping the zynq defconfigs to 2022.1 instead
 > of 2021.2.

 > Based on the feedback, I will keep the defconfigs using tarballs
 > instead of git cloning.  I plan to migrate the zynqmp defconfigs to
 > tarballs as well.

 > Do not hesitate if you have any additional feedback or questions.

Thanks, sorry I didn't get back to you.

-- 
Bye, Peter Korsgaard
_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply	[flat|nested] 15+ messages in thread

end of thread, other threads:[~2022-05-02  7:57 UTC | newest]

Thread overview: 15+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-04-08 14:55 [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager via buildroot
2022-04-08 14:55 ` [Buildroot] [PATCH v1 2/4] configs/zynq_zed_defconfig: " Neal Frager via buildroot
2022-04-14 19:59   ` Arnout Vandecappelle
2022-04-14 22:24     ` Luca Ceresoli
2022-04-15  7:01     ` Neal Frager
2022-04-08 14:55 ` [Buildroot] [PATCH v1 3/4] configs/zynq_microzed_defconfig: " Neal Frager via buildroot
2022-04-08 14:55 ` [Buildroot] [PATCH v1 4/4] configs/zynq_qmtech_defconfig: bump to ext4 and distro boot Neal Frager via buildroot
2022-04-14  8:55 ` [Buildroot] [PATCH v1 1/4] configs/zynq_zc706_defconfig: bump to Xilinx 2021.2 Neal Frager
2022-04-14 19:54 ` Arnout Vandecappelle
2022-04-15  6:52   ` Neal Frager
2022-04-17  6:48     ` Neal Frager
2022-05-02  7:43       ` Neal Frager
2022-05-02  7:57         ` Peter Korsgaard
2022-04-14 22:20 ` Luca Ceresoli
2022-04-15  7:11   ` Neal Frager

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.